@@ -10,22 +10,12 @@
 #' @export
 #' @param prompt the string printed when prompting the user for input.
 pinentry <- function(prompt = "Enter your GPG passphrase:"){
-  if(is_unix() && has_pinentry()){
-    tryCatch({
+  if(is_unix() && isatty(stdin()) && has_pinentry()){
+    try({
       return(pinentry_exec(prompt))
-    }, error = identity)
-  }
-  if(is.function(FUN <- getOption("askpass"))){
-    return(FUN(prompt))
-  }
-  if(interactive()){
-    return(readline(prompt))
-  }
-  if(is_windows()){
-    stop("Passphrase required but no suitable pinentry program found. Try installing GPG4Win.")
-  } else {
-    stop("Passphrase required but no suitable pinentry program found. Need to configure gpg-agent.")
+    })
   }
+  askpass::askpass(prompt = prompt)
 }
 
 is_cmd_build <- function(){
@@ -47,7 +37,8 @@ has_pinentry <- function(){
 # in POSIX, "/dev/tty" means current CTTY
 pinentry_exec <- function(str){
   input <- c(paste("SETPROMPT", str), "GETPIN")
-  res <- system2("pinentry", paste("-T", '/dev/tty'), input = input, stdout = TRUE)
+  tty <- system2("tty", stdout = TRUE)
+  res <- system2("pinentry", paste("-T", tty, '-C', 'UTF-8'), input = input, stdout = TRUE)
   errors <- res[grepl("^ERR ", res)]
   if(length(errors))
     stop(sub("^ERR", "Pinentry error", errors[1]), call. = FALSE)
